#
# spec file for package libadlmidi
#
# Copyright (c) 2022 SUSE LLC
# Copyright (c) 2019-2022, Martin Hauke <mardnh@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sover 1
%define libname libADLMIDI
Name:           libadlmidi
%define hyphver 1.5.1
Version:        1.5.1
Release:        1.3
Summary:        A software MIDI synthesizer library with OPL3 emulation
License:        GPL-3.0-only AND LGPL-3.0-only
Group:          Development/Languages/C and C++
URL:            https://github.com/Wohlstand/%{libname}
Source:         https://github.com/Wohlstand/libADLMIDI/archive/refs/tags/v%{hyphver}.tar.gz#/%{libname}-%{hyphver}.tar.gz
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(sdl2)

%description
A software MIDI synthesizer library with OPL3 emulation (FM synthesis).
The library is based on the ADLMIDI, a multiplatform MIDI player with OPL3 emulation:
https://bisqwit.iki.fi/source/adlmidi.html

%package -n %{libname}%{sover}
Summary:        A Software MIDI Synthesizer library with OPL3 (YMF262) emulator
Group:          System/Libraries

%description -n %{libname}%{sover}
A software MIDI synthesizer library with OPL3 emulation (FM synthesis).
The library is based on the ADLMIDI, a multiplatform MIDI player with OPL3 emulation:
https://bisqwit.iki.fi/source/adlmidi.html

%package -n adlmidi-tools
Summary:        A MIDI player with OPL3 emulation
Group:          Productivity/Multimedia/Sound/Players

%description -n adlmidi-tools
AdlMIDI is a commandline program that plays MIDI files using software
OPL3 emulation (FM synthesis).

%package devel
Summary:        Header files for libADLMIDI
Group:          Development/Libraries/C and C++
Requires:       libADLMIDI%{sover} = %{version}

%description devel
Development and header files for libADLMIDI.

%prep
%setup -q -n %{libname}-%{hyphver}

%build
%cmake \
  -DlibADLMIDI_STATIC=OFF \
  -DlibADLMIDI_SHARED=ON \
  -DlibADLMIDI_SHARED=ON \
  -DWITH_MIDIPLAY=ON \
  -DWITH_CPP_EXTRAS=ON \
  -DWITH_ADLMIDI2=ON
%cmake_build

%install
%cmake_install
rm -r %{buildroot}%{_datadir}/doc/

%post   -n libADLMIDI%{sover} -p /sbin/ldconfig
%postun -n libADLMIDI%{sover} -p /sbin/ldconfig

%files -n %{libname}%{sover}
%license LICENSE LICENSE.GPL-3.txt LICENSE.LGPL-2.1.txt
%{_libdir}/%{libname}.so.%{sover}*

%files -n adlmidi-tools
%{_bindir}/adlmidi2
%{_bindir}/adlmidiplay

%files devel
%doc AUTHORS README.md
%{_includedir}/adlmidi.h
%{_libdir}/%{libname}.so
%{_libdir}/pkgconfig/%{libname}.pc

%changelog
* Mon Oct 31 2022 Martin Hauke <mardnh@gmx.de>
- Update to version 1.5.1
  * Added an ability to disable the automatical arpeggio.
  * Added an ability to set the count of loops (how many times to
    play the song).
  * Added an ability to disable/enable the playing of selected
    MIDI channels.
  * Fixed memory damages and crashes while playing XMI files.
  * Added bank-specific MT32 defaults (to don't confuse XMI
    playback between different games, works for AIL and IBK only,
    and for WOPL if set at the header).
  * Added the chip channels allocation mode option.
  * Fixed the playback of multi-song XMI files.
  * Added an ability to switch the XMI song on the fly.
* Mon May  3 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 1.5.0.1.1
  * Fixed an incorrect timer processing when using a real-time
    interface
* Mon Sep 28 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 1.5.0
  * Drum note length expanding is now supported in real-time mode.
  * Channels manager has been improved.
  * Nuked OPL3 1.8 emulator got some optimizations ported from 1.7
  where they are was applied previously.
  * Reworked rhythm-mode percussions system, WOPL banks with
    rhythm-mode percussions
  * Added Public Domain Opal OPL3 emulator made by Reality (a team
    who originally made the Reality Adlib Tracker).
  * Added LGPL licensed JavaOPL3 emulator made by Robson Cozendey
    in Java and later rewritten into C++ for GZDoom.
  * Fully rewritten an embedded bank database format, embedded
    banks now supports a wider set (more than 127:127 instruments
    in one bank).
  * Improved accuracy of the DMX volume model, include the buggy
    AM interpretation.
  * Improved accuracy of Apogee volume model, include the bug of
    AM instruments.
  * Improved accuracy of the Win9X volume model.
  * Removed C++ extras. C++-bounded instruments tester is useless
    since a real-time MIDI API can completely replace it.
  * Added AIL volume model.
  * Added Generic FM variant of Win9X volume model.
  * Fixed an incorrect work of CC-121.
  * Added HMI volume model.
  * Added frequency models, assigned to every volume model: AIL,
    HMI, DMX, Apogee, 9X, and the Generic formula.
- Drop patch:
  * libadlmidi-fix-arm.patch (not longer needed)
* Tue Jun  9 2020 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Fix build on Arm with upstream patch:
  * libadlmidi-fix-arm.patch
* Mon Mar 11 2019 Martin Hauke <mardnh@gmx.de>
- Initial package, version 1.4.0.1
